aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJeff Morriss <jeff.morriss.ws@gmail.com>2019-01-08 15:24:11 -0500
committerAnders Broman <a.broman58@gmail.com>2019-01-09 04:22:54 +0000
commit6739523a02d8f916bbad8b230aa15db11c651d82 (patch)
tree2d546b984a81ee1935f1de5909809f34565f2018
parentfd4d41fc329ca33663e0aa12fbccae14fbe9e3fd (diff)
valgrind-wireshark: default to looking in run/ for our binaries.
If33a39c26714ebe699463d1c8c67469025767efb made this change for the other scripts. Change-Id: I158c1c2d0b564a115443e96a6d90733c2ffff071 Reviewed-on: https://code.wireshark.org/review/31459 Petri-Dish: Jeff Morriss <jeff.morriss.ws@gmail.com> Tested-by: Petri Dish Buildbot Reviewed-by: Anders Broman <a.broman58@gmail.com>
-rwxr-xr-xtools/valgrind-wireshark.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/valgrind-wireshark.sh b/tools/valgrind-wireshark.sh
index 8209a09598..c5592e0b02 100755
--- a/tools/valgrind-wireshark.sh
+++ b/tools/valgrind-wireshark.sh
@@ -11,9 +11,9 @@
#
# SPDX-License-Identifier: GPL-2.0-or-later
# Directory containing tshark or wireshark. Default current directory.
if [ -z "$WIRESHARK_BIN_DIR" ]; then
- WIRESHARK_BIN_DIR=.
+ WIRESHARK_BIN_DIR=run
fi
# Use tshark by default
@@ -11,9 +11,9 @@
#
# SPDX-License-Identifier: GPL-2.0-or-later
-# Directory containing tshark or wireshark. Default current directory.
+# Directory containing tshark or wireshark. Default: cmake run directory.
if [ -z "$WIRESHARK_BIN_DIR" ]; then